pub enum Feature {
Show 22 variants
TestDummy,
TimeTravel,
GlueSchemaRegistry,
SnowflakeSink,
RedisSinkStream,
DynamoDbSink,
OpenSearchSink,
BigQuerySink,
ClickHouseSharedEngine,
SecretManagement,
SqlServerSink,
SqlServerCdcSource,
CdcAutoSchemaChange,
IcebergSinkWithGlue,
ElasticDiskCache,
ResourceGroup,
DatabaseFailureIsolation,
IcebergCompaction,
SinkAutoSchemaChange,
StateTableMemoryPreload,
LocalityBackfill,
SinkSinceTimestamp,
}Expand description
A set of features that are available based on the license.
JSON schema
{
"title": "Feature",
"description": "A set of features that are available based on the license.",
"oneOf": [
{
"description": "A dummy feature for testing purposes.",
"type": "string",
"const": "TestDummy"
},
{
"description": "Query historical data within the retention period.",
"type": "string",
"const": "TimeTravel"
},
{
"description": "Use Schema Registry from AWS Glue rather than Confluent.",
"type": "string",
"const": "GlueSchemaRegistry"
},
{
"description": "Delivering data to SnowFlake.",
"type": "string",
"const": "SnowflakeSink"
},
{
"description": "Delivering data to redis stream.",
"type": "string",
"const": "RedisSinkStream"
},
{
"description": "Delivering data to DynamoDb.",
"type": "string",
"const": "DynamoDbSink"
},
{
"description": "Delivering data to OpenSearch.",
"type": "string",
"const": "OpenSearchSink"
},
{
"description": "Delivering data to BigQuery.",
"type": "string",
"const": "BigQuerySink"
},
{
"description": "Delivering data to Shared tree on clickhouse cloud",
"type": "string",
"const": "ClickHouseSharedEngine"
},
{
"description": "Secret management.",
"type": "string",
"const": "SecretManagement"
},
{
"description": "Sink data from RisingWave to SQL Server.",
"type": "string",
"const": "SqlServerSink"
},
{
"description": "CDC source connector for Sql Server.",
"type": "string",
"const": "SqlServerCdcSource"
},
{
"description": "Auto replicate upstream DDL to CDC Table.",
"type": "string",
"const": "CdcAutoSchemaChange"
},
{
"description": "Delivering data to Iceberg with Glue catalog.",
"type": "string",
"const": "IcebergSinkWithGlue"
},
{
"description": "Disk cache and refilling to boost performance and reduce object store access cost.",
"type": "string",
"const": "ElasticDiskCache"
},
{
"description": "Resource group to isolate workload and failure.",
"type": "string",
"const": "ResourceGroup"
},
{
"description": "Failure isolation between databases.",
"type": "string",
"const": "DatabaseFailureIsolation"
},
{
"description": "Auto iceberg compaction.",
"type": "string",
"const": "IcebergCompaction"
},
{
"description": "Sink auto schema change.",
"type": "string",
"const": "SinkAutoSchemaChange"
},
{
"description": "Support state table memory preload for boosting performance.",
"type": "string",
"const": "StateTableMemoryPreload"
},
{
"description": "Support locality backfill for complex streaming queries.",
"type": "string",
"const": "LocalityBackfill"
},
{
"description": "Create sinks from a historical timestamp.",
"type": "string",
"const": "SinkSinceTimestamp"
}
]
}Variants
TestDummy
A dummy feature for testing purposes.
TimeTravel
Query historical data within the retention period.
GlueSchemaRegistry
Use Schema Registry from AWS Glue rather than Confluent.
SnowflakeSink
Delivering data to SnowFlake.
RedisSinkStream
Delivering data to redis stream.
DynamoDbSink
Delivering data to DynamoDb.
OpenSearchSink
Delivering data to OpenSearch.
BigQuerySink
Delivering data to BigQuery.
Delivering data to Shared tree on clickhouse cloud
SecretManagement
Secret management.
SqlServerSink
Sink data from RisingWave to SQL Server.
SqlServerCdcSource
CDC source connector for Sql Server.
CdcAutoSchemaChange
Auto replicate upstream DDL to CDC Table.
IcebergSinkWithGlue
Delivering data to Iceberg with Glue catalog.
ElasticDiskCache
Disk cache and refilling to boost performance and reduce object store access cost.
ResourceGroup
Resource group to isolate workload and failure.
DatabaseFailureIsolation
Failure isolation between databases.
IcebergCompaction
Auto iceberg compaction.
SinkAutoSchemaChange
Sink auto schema change.
StateTableMemoryPreload
Support state table memory preload for boosting performance.
LocalityBackfill
Support locality backfill for complex streaming queries.
SinkSinceTimestamp
Create sinks from a historical timestamp.
Implementations
Sourceimpl Feature
impl Feature
Sourcepub fn description(self) -> &'static str
pub fn description(self) -> &'static str
Description of the feature.
Sourcepub(crate) fn all_as_of_2_5() -> &'static [Feature]
pub(crate) fn all_as_of_2_5() -> &'static [Feature]
Get a slice of all features available as of 2.5 (before we introduce custom tier).
Sourceimpl Feature
impl Feature
Sourcepub(crate) fn check_available_with(
self,
manager: &LicenseManager,
) -> Result<(), FeatureNotAvailable>
pub(crate) fn check_available_with( self, manager: &LicenseManager, ) -> Result<(), FeatureNotAvailable>
Check whether the feature is available based on the given license manager.
Sourcepub fn check_available(self) -> Result<(), FeatureNotAvailable>
pub fn check_available(self) -> Result<(), FeatureNotAvailable>
Check whether the feature is available based on the current license.